@@ -3,7 +3,7 @@ use Mojo::Base -base;
 
 use Carp 'croak';
 use Mojo::Loader 'data_section';
-use Mojo::Util 'slurp';
+use Mojo::Util qw(decode slurp);
 
 use constant DEBUG => $ENV{MOJO_MIGRATIONS_DEBUG} || 0;
 
@@ -18,7 +18,7 @@ sub from_data {
     data_section($class //= caller, $name // $self->name));
 }
 
-sub from_file { shift->from_string(slurp pop) }
+sub from_file { shift->from_string(decode 'UTF-8', slurp pop) }
 
 sub from_string {
   my ($self, $sql) = @_;
